﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;
using System.Drawing.Imaging;
using System.IO;

namespace SplitCode
{
    public class TiffCoder : ICoder
    {
        private Image _image;
        private FrameDimension _dim;
        private string _inputImageName;
        private ConfObj _config;

        #region ICoder Members

        public void Prepare(ConfObj config)
        {
            _config = config;
        }

        public int LoadImage(string fileName)
        {
            _inputImageName = fileName;
            _image = Image.FromFile(fileName);
            Guid guid = _image.FrameDimensionsList[0];
            _dim = new FrameDimension(guid);
            return _image.GetFrameCount(_dim);
        }


        public void Save(int pageNum)
        {
            _image.SelectActiveFrame(_dim, pageNum);
            string outputFileName = null;

            if (String.IsNullOrEmpty(_config.outDir))
            {
                outputFileName = Path.Combine(Path.GetDirectoryName(_inputImageName), String.Format("{0}_{1}.tif",
                    Path.GetFileNameWithoutExtension(_inputImageName), pageNum + 1));
            }
            else
            {
                outputFileName = Path.Combine(_config.outDir, String.Format("{0}_{1}.tif",
                    Path.GetFileNameWithoutExtension(_inputImageName), pageNum + 1));
            }

            if (!_config.doOverwrite)
            {
                outputFileName = HelperMethods.ModifyFileName(outputFileName);
            }

            _image.Save(outputFileName);
        }

        public void Close()
        {
            _image.Dispose();
        }

        #endregion
    }
}
